PackageVersion class

Defines package versions used by FKIT when configuring dependencies.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

buildRunner → const String
The supported build_runner package version.
flutterLauncherIcons → const String
The supported flutter_launcher_icons package version.
flutterNativeSplash → const String
The supported flutter_native_splash package version.
freezed → const String
The supported freezed package version.