TemplateRenderer class
Provides utilities for rendering FKIT templates.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
render(
{required String templateRoot, required String template, Map< String, String> variables = const {}}) → Future<String> -
Loads and renders a template using the provided
variables. -
renderString(
String value, Map< String, String> variables) → String -
Replaces template placeholders in
valueusing the providedvariables.