RegistrationResolver class
Resolves dependency injection registrations for generated components.
Constructors
- RegistrationResolver()
-
Creates a registration resolver.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
GeneratorContext context) → Future< List< ResolvedRegistration> > -
Resolves dependency injection registrations using the provided
context. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited