ResolvedRegistration class
Represents a resolved dependency injection registration.
Constructors
-
ResolvedRegistration({required RegistrationLifecycle lifecycle, required String abstraction, required String implementation, required String variable, required List<
String> dependencies}) -
Creates a resolved dependency injection registration.
const
Properties
- abstraction → String
-
HomeRepository
final
-
dependencies
→ List<
String> -
homeRemoteDatasource: sl(),
homeLocalDatasource: sl(),
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- implementation → String
-
HomeRepositoryImpl
final
- lifecycle → RegistrationLifecycle
-
The lifecycle used to register the dependency.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variable → String
-
homeRepository
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited