ModuleOptionResolver class
Resolves configured option values for an FKIT module.
Constructors
- ModuleOptionResolver()
-
Creates a module option resolver.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
ModuleDefinition module) → Future< Map< String, dynamic> > -
Resolves option values for the provided
module. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited