isComplete property
bool
get
isComplete
Whether the route definition and registration are both present.
Implementation
bool get isComplete => hasDefinition && hasRegistration;
Whether the route definition and registration are both present.
bool get isComplete => hasDefinition && hasRegistration;