RouteRenderer class abstract interface

Defines the contract for rendering application routes.

Implementations integrate resolved routes into the project's routing configuration.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render({required GeneratorContext context, required List<ResolvedRoute> routes}) Future<void>
Renders resolved routes using the provided generation configuration.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited