RouteImportResolver class

Resolves relative import paths between router and screen files.

Constructors

RouteImportResolver()
Creates a route import resolver.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({required String routerFile, required String screenFile}) String
Resolves the relative import path from routerFile to screenFile.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited