ConfigMapper class

Maps FKIT models into wizard setup models.

Constructors

ConfigMapper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toFlavorSetup(InitConfig config) FlavorSetup
Creates a FlavorSetup from the provided config.
toPlatformSetup(InitConfig config) PlatformSetup
Creates a PlatformSetup from the provided config.