BuildPlatform enum
Defines the application build platforms supported by FKIT.
Values
- apk → const BuildPlatform
-
Builds an Android application package (APK).
- aab → const BuildPlatform
-
Builds an Android App Bundle (AAB).
- ipa → const BuildPlatform
-
Builds an iOS application archive (IPA).
- web → const BuildPlatform
-
Builds a web application.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String value) → BuildPlatform -
Creates a build platform from the provided
value.
Constants
-
values
→ const List<
BuildPlatform> - A constant List of the values in this enum, in order of their declaration.