BuildResult class

Represents the result of an application build.

Constructors

BuildResult({required String artifactPath})
Creates a build result with the specified artifactPath.

Properties

artifactPath String
The path to the generated build artifact.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited