EnvironmentConfig class

Defines environment configuration for an FKIT project.

Constructors

EnvironmentConfig({required bool enabled, required Map<String, EnvironmentDetails> configurations})
Creates an FKIT environment configuration.
const
EnvironmentConfig.fromMap(Map map)
Creates environment configuration from the provided map.
factory

Properties

configurations Map<String, EnvironmentDetails>
Environment configurations keyed by target name.
final
enabled bool
Whether environment configuration is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configurationFor(String target) EnvironmentDetails?
Returns environment configuration for the specified target.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited