FirebasePlatformEntry class

Associates a platform name with its Firebase configuration.

Constructors

FirebasePlatformEntry(String name, FirebasePlatform platform)
Creates a Firebase platform entry.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the platform.
final
platform FirebasePlatform
The Firebase configuration associated with the platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited