FirebasePlatform class

Defines Firebase configuration for a specific application platform.

Constructors

FirebasePlatform({required String appId, required String options})
Creates a Firebase platform configuration.
const
FirebasePlatform.fromMap(Map<String, dynamic> map)
Creates a Firebase platform configuration from the provided map.
factory

Properties

appId String
The Firebase application identifier for the platform.
final
hashCode int
The hash code for this object.
no setterinherited
options String
The path to the generated Firebase options file.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts this Firebase platform configuration to a map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited