LauncherIconConfig class

Defines launcher icon configuration for an FKIT project.

Constructors

LauncherIconConfig({required String imagePath, required bool android, required bool ios, required bool web, required String adaptiveBackground, required String adaptiveForeground, String? adaptiveMonochrome, required bool removeAlphaIos})
Creates a launcher icon configuration.
const
LauncherIconConfig.fromMap(Map map)
Creates a launcher icon configuration from the provided map.
factory

Properties

adaptiveBackground String
The background value used for Android adaptive icons.
final
adaptiveForeground String
The path to the foreground image used for Android adaptive icons.
final
adaptiveMonochrome String?
The optional path to the monochrome image used for adaptive icons.
final
android bool
Whether Android launcher icon generation is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
imagePath String
The path to the source launcher icon image.
final
ios bool
Whether iOS launcher icon generation is enabled.
final
removeAlphaIos bool
Whether alpha transparency should be removed from generated iOS icons.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
web bool
Whether web launcher icon generation is enabled.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this launcher icon configuration to a map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited