ModuleFile class

Defines a file generated by an FKIT module.

Constructors

ModuleFile({required String template, required String output, String? when})
Creates a module file configuration.
const
ModuleFile.fromMap(Map map)
Creates a module file configuration from the provided map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isConditional bool
Whether the file is generated conditionally.
no setter
output String
The output path where the generated file is written.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
template String
The path to the source template file.
final
when String?
The optional module option controlling whether this file is generated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited