ModuleInstallationResult class
Represents the result of an FKIT module installation.
Constructors
- ModuleInstallationResult({required String moduleName, required bool installed, required bool requiresBuildRunner})
-
Creates a module installation result.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- installed → bool
-
Whether the module was installed successfully.
final
- moduleName → String
-
The name of the module associated with the installation.
final
- requiresBuildRunner → bool
-
Whether the installed module requires build runner execution.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited