TemplateBarrel class
Defines barrel file generation and synchronization configuration for an FKIT template.
Constructors
-
TemplateBarrel({required bool enabled, required String file, required List<
String> exports, required List<String> ignore}) -
Creates a template barrel configuration.
const
- TemplateBarrel.fromMap(Map map)
-
Creates a template barrel configuration from the provided
map.factory
Properties
- enabled → bool
-
Whether barrel synchronization is enabled.
final
-
exports
→ List<
String> -
Folders to scan.
final
- file → String
-
Output barrel file.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ignore
→ List<
String> -
Glob patterns to ignore.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited