TemplateBootstrap class

Defines project bootstrap configuration for an FKIT template.

Constructors

TemplateBootstrap({required bool enabled, required TemplateBootstrapFile? app, required TemplateBootstrapFile? main})
Creates a template bootstrap configuration.
const
TemplateBootstrap.empty()
Creates an empty template bootstrap configuration.
const
TemplateBootstrap.fromMap(Map map)
Creates a template bootstrap configuration from the provided map.
factory

Properties

app TemplateBootstrapFile?
The optional bootstrap configuration for the application file.
final
enabled bool
Whether project bootstrapping is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
main TemplateBootstrapFile?
The optional bootstrap configuration for the main entry-point file.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited