TemplateBootstrapFile class
Defines a file generated during project bootstrapping.
Constructors
- TemplateBootstrapFile({required String template, required String output})
-
Creates a template bootstrap file configuration.
const
- TemplateBootstrapFile.fromMap(Map map)
-
Creates a template bootstrap file configuration from the provided
map.factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited