TemplateFeature class

Defines the folders and files generated for an FKIT feature.

Constructors

TemplateFeature({required List<String> folders, required List<TemplateFile> files})
Creates a template feature configuration.
const
TemplateFeature.fromMap(Map map)
Creates a template feature configuration from the provided map.
factory

Properties

files List<TemplateFile>
The template files generated for the feature.
final
folders List<String>
The directories created for the generated feature.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited