TemplateFile class
Defines a template file and its generated output location.
Constructors
- TemplateFile({required String template, required String output})
-
Creates a template file configuration.
const
- TemplateFile.fromMap(Map map)
-
Creates a template file configuration from the provided
map.factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited