TemplateGroup class

Defines a group of related components in an FKIT template.

Constructors

TemplateGroup({required String description, required List<String> components})
Creates a template component group.
const
TemplateGroup.fromMap(Map map)
Creates a template component group from the provided map.
factory

Properties

components List<String>
The components included in the group.
final
description String
A description of the component group.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited