TemplateRegistration class

Defines dependency injection registration metadata for a template component.

Constructors

TemplateRegistration({required String component, required String folder, required RegistrationLifecycle lifecycle, String? implementation})
Creates a template registration configuration.
const
TemplateRegistration.fromMap(String component, Map map)
Creates a template registration from the provided component and map.
factory

Properties

component String
The component associated with the registration.
final
folder String
The directory containing the component implementation.
final
hashCode int
The hash code for this object.
no setterinherited
implementation String?
The optional implementation associated with the registered component.
final
isFactory bool
Whether the component uses the factory registration lifecycle.
no setter
isLazySingleton bool
Whether the component uses the lazy singleton registration lifecycle.
no setter
isSingleton bool
Whether the component uses the singleton registration lifecycle.
no setter
lifecycle RegistrationLifecycle
The dependency injection lifecycle used for the registration.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited