TemplateRouter class
Defines routing configuration for an FKIT template.
Constructors
-
TemplateRouter({required bool enabled, required String strategy, required String routeFile, required String routerFile, required String initialRoute, required String screenFolder, required String screenSuffix, required List<
String> ignore}) -
Creates a template routing configuration.
const
- TemplateRouter.fromMap(Map map)
-
Creates a template routing configuration from the provided
map.factory
Properties
- enabled → bool
-
Whether routing integration is enabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ignore
→ List<
String> -
The routes or files excluded from routing integration.
final
- initialRoute → String
-
The initial route configured for the application.
final
- isGoRouter → bool
-
Whether the configured routing strategy uses GoRouter.
no setter
- isManual → bool
-
Whether the configured routing strategy uses manual routing.
no setter
- routeFile → String
-
The path to the generated or maintained route file.
final
- routerFile → String
-
The path to the application's router configuration file.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenFolder → String
-
The directory containing generated screen files.
final
- screenSuffix → String
-
The suffix used to identify screen files.
final
- strategy → String
-
The routing strategy used by the template.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited