BuildService class

Manages application build and run operations for FKIT projects.

Constructors

BuildService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build({required BuildPlatform platform, required String flavor}) Future<BuildResult>
Builds the application and returns the generated build result.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run({required BuildPlatform platform, required String flavor, BuildMode mode = BuildMode.debug}) Future<void>
Runs the application using the provided configuration and options.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited