ConfigUpdateService class
Updates individual FKIT project configuration sections.
Constructors
- ConfigUpdateService()
-
Creates a configuration update service.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
{required ConfigSection section, required InitConfig config}) → Future< void> -
Updates the specified configuration
section.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited