LauncherIconService class

Manages the Flutter launcher icons configuration.

Provides utilities for loading, saving, validating, and interactively configuring the flutter_launcher_icons.yaml file.

Constructors

LauncherIconService()
Creates a launcher icon service.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure() Future<LauncherIconConfig>
Interactively collects launcher icon configuration from the user.
exists() Future<bool>
Returns whether the launcher icon configuration file exists.
load() Future<LauncherIconConfig?>
Loads the launcher icon configuration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(LauncherIconConfig config) Future<void>
Saves the provided launcher icon config to the configuration file.
toString() String
A string representation of this object.
inherited
validate() Future<List<String>>
Validates the launcher icon configuration.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fileName → const String
The default launcher icon configuration file name.