LocalizationService class
Manages localization setup, generation, and validation for Flutter projects.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
doctor(
) → Future< void> - Validates the localization configuration of the current Flutter project.
-
generate(
) → Future< void> - Configures and generates localization resources for the current project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setup(
) → Future< void> - Sets up localization support for the current Flutter project.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited