doctor method
Validates the localization configuration of the current Flutter project.
Reports an error when the localization configuration is invalid.
Implementation
Future<void> doctor() async {
LoggerService.section('Localization Doctor');
_ensureFlutterProject();
final config = await ConfigService.load();
LocalizationValidator.validate(config);
LoggerService.success('Localization configuration looks good.');
}