ModuleService class
Loads module definitions from FKIT templates.
Constructors
- ModuleService()
-
Creates a module service.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
load(
{required String template, required String module}) → Future< ModuleDefinition> -
Loads the specified
moduledefinition from atemplate. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited