localDatasourceImplBase property
The local datasource implementation file name without its Dart extension.
Implementation
late final String localDatasourceImplBase =
'${featureSnake}_local_datasource_impl';
The local datasource implementation file name without its Dart extension.
late final String localDatasourceImplBase =
'${featureSnake}_local_datasource_impl';