stateBase property
The Bloc state file name without its Dart extension.
Implementation
late final String stateBase = '${featureSnake}_state';
The Bloc state file name without its Dart extension.
late final String stateBase = '${featureSnake}_state';