ProjectBootstrapService class
Bootstraps a Flutter project using the selected FKIT template.
Performs template-defined project setup and generation tasks using the provided project configuration.
- Mixed-in types
Constructors
- ProjectBootstrapService()
-
Creates a project bootstrap service.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bootstrap(
{required InitConfig config, required TemplateDefinition template}) → Future< bool> -
Bootstraps the project using the provided
configandtemplate. -
confirmOverwrite(
String description) → Future< bool> -
Prompts the user to confirm overwriting an existing item.
inherited
-
ensureDirectory(
Directory directory) → Future< void> -
Ensures that the specified
directoryexists.inherited -
generateTemplate(
{required String templateRoot, required String template, required String output, required Map< String, String> variables, bool overwrite = false}) → Future<void> -
Renders a template and writes the generated content to
output.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
path(
String featurePath, String relative) → String -
Creates a path by combining
featurePathwith arelativepath.inherited -
resolveVariables(
String value, Map< String, String> variables) → String -
Replaces template placeholders in
valueusing the providedvariables.inherited -
shouldGenerate(
FileSystemEntity entity, {bool overwrite = false}) → Future< bool> -
Determines whether the specified
entityshould be generated.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
writeFile(
{required File file, required String content, bool overwrite = false}) → Future< void> -
Writes
contentto the specifiedfile.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited