ProjectSetupService class
Configures an FKIT project using the selected template.
Performs project setup tasks based on the provided project configuration and template definition.
Constructors
- ProjectSetupService()
-
Creates a project setup service.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setup(
{required InitConfig config, required TemplateDefinition template}) → Future< bool> -
Sets up the project using the provided
configandtemplate. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited