PromptService class

Provides utilities for collecting user input from the command line.

Constructors

PromptService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

ask(String question, {String? defaultValue}) String
Prompts the user with a question and returns the entered value.
confirm(String question, {bool defaultValue = false}) bool
Prompts the user to confirm a question.