AppPlatform class

Provides platform identifiers and predefined platform groups used by FKIT.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

all → const List<String>
All platforms supported by FKIT.
android → const String
The Android platform identifier.
ios → const String
The iOS platform identifier.
mobile → const List<String>
The platforms considered mobile platforms.
web → const String
The web platform identifier.