PathUtils class

Provides utilities for working with file and directory paths.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

directory(String path) String
Returns the directory portion of the specified path.
fileName(String path) String
Returns the file name portion of the specified path.
normalize(String path) String
Normalizes path by replacing backslashes with forward slashes.
relativeImport({required String from, required String to}) String
Returns the relative import path from one file to another.