FlavorSetup class
Defines the flavor configuration for an FKIT project.
Contains settings for enabling flavors, selecting the default flavor, and defining the available project flavors.
Constructors
-
FlavorSetup({required bool enabled, required String defaultFlavor, required List<
String> flavors}) -
Creates a flavor configuration.
const
Properties
- defaultFlavor → String
-
The name of the default flavor used by the project.
final
- enabled → bool
-
Whether flavor support is enabled.
final
-
flavors
→ List<
String> -
The available application flavors.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited