defaultFlavor property
The name of the default flavor used by the project.
Defaults to main when flavoring is disabled.
Implementation
final String defaultFlavor;
The name of the default flavor used by the project.
Defaults to main when flavoring is disabled.
final String defaultFlavor;