FirebaseStep class
Collects Firebase configuration during the initialization wizard.
- Inheritance
-
- Object
- WizardStep<
FirebaseConfig> - FirebaseStep
Constructors
- FirebaseStep({required PlatformSetup platforms, required FlavorSetup flavors, FirebaseConfig? current})
- Creates a Firebase configuration step.
Properties
- current → FirebaseConfig?
-
The existing Firebase configuration.
final
- flavors → FlavorSetup
-
The flavor configuration used to determine Firebase targets.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- platforms → PlatformSetup
-
The project platforms used to determine Firebase configuration.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
collect(
) → FirebaseConfig -
Collects and returns the value produced by this wizard step.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited