FlavorStep constructor
FlavorStep(
- PlatformSetup platforms
Creates a flavor configuration step for the specified platforms.
Implementation
FlavorStep(this.platforms);
Creates a flavor configuration step for the specified platforms.
FlavorStep(this.platforms);