LocalizationStep class

Collects localization configuration during the initialization wizard.

Inheritance

Constructors

LocalizationStep({LocalizationConfig? current})
Creates a localization configuration step.

Properties

current LocalizationConfig?
The existing localization configuration.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

collect() LocalizationConfig
Collects and returns the value produced by this wizard step.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited