ConstructorParameter class

Represents a parameter declared in a Dart constructor.

Contains metadata about the parameter's type, name, and whether it is named or required.

Constructors

ConstructorParameter({required String type, required String name, required bool isNamed, required bool isRequired})
Creates a constructor parameter description.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isNamed bool
Whether the parameter is a named parameter.
final
isRequired bool
Whether the parameter is required.
final
name String
The name of the parameter.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The declared Dart type of the parameter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited