ExistingRouteResolver class
Resolves the integration status of existing application routes.
Constructors
- ExistingRouteResolver()
-
Creates an existing route resolver.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
{required List< ResolvedRoute> discoveredRoutes, required String routeContent, required String routerContent, required String routerFile}) → List<ExistingRouteStatus> - Resolves the status of existing routes.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited