FirebaseDetails class
Defines Firebase configuration for all supported application platforms.
Constructors
- FirebaseDetails({FirebasePlatform? android, FirebasePlatform? ios, FirebasePlatform? web})
-
Creates Firebase configuration for the supported platforms.
const
-
FirebaseDetails.fromMap(Map<
String, dynamic> map) -
Creates Firebase platform configuration from the provided
map.factory
Properties
- android → FirebasePlatform?
-
The Firebase configuration for Android.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ios → FirebasePlatform?
-
The Firebase configuration for iOS.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- web → FirebasePlatform?
-
The Firebase configuration for web.
final
Methods
-
entries(
) → Iterable< FirebasePlatformEntry> - Returns the configured Firebase platforms as named entries.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this Firebase configuration to a map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited