InitConfig class

Defines the complete configuration of an FKIT project.

Constructors

InitConfig({required String version, required String projectName, required bool useFvm, required bool android, required bool ios, required bool web, required bool flavoringEnabled, required String defaultFlavor, required Map<String, FlavorDetails> flavors, required bool localizationEnabled, required String arbDir, required String outputDir, required String outputFile, required String defaultLocale, required List<String> locales, required String debugInfo, required bool obfuscate, required String mainEntry, required String testerGroup, required String featureDir, required String defaultTemplate})
Creates an FKIT project configuration.
const
InitConfig.fromMap(Map map)
Creates an FKIT project configuration from the provided map.
factory

Properties

android bool
Whether Android platform support is enabled.
final
arbDir String
The directory containing localization ARB files.
final
debugInfo String
The directory where debug information is generated.
final
defaultFlavor String
The name of the default application flavor.
final
defaultLocale String
The default locale used by the project.
final
defaultTemplate String
The default template used for code generation.
final
featureDir String
The root directory where features are generated.
final
flavoringEnabled bool
Whether application flavoring is enabled.
final
flavors Map<String, FlavorDetails>
The configured application flavors keyed by flavor name.
final
hashCode int
The hash code for this object.
no setterinherited
ios bool
Whether iOS platform support is enabled.
final
locales List<String>
The locales supported by the project.
final
localizationEnabled bool
Whether localization support is enabled.
final
mainEntry String
The main Dart entry-point file used by the project.
final
obfuscate bool
Whether release builds use code obfuscation.
final
outputDir String
The directory where generated localization files are written.
final
outputFile String
The name of the generated localization output file.
final
projectName String
The name of the Flutter project.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testerGroup String
The Firebase App Distribution tester group.
final
useFvm bool
Whether Flutter Version Management (FVM) is enabled.
final
version String
The FKIT configuration schema version.
final
web bool
Whether web platform support is enabled.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited