ModulePackage class
Defines a package dependency required by an FKIT module.
Constructors
- ModulePackage({required String name, required String version, String? when})
-
Creates a module package configuration.
const
- ModulePackage.fromValue({required String name, required dynamic value})
-
Creates a module package from the provided
nameand configurationvalue.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConditional → bool
-
Whether the package is included conditionally.
no setter
- name → String
-
The name of the package.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
The version constraint of the package.
final
- when → String?
-
The optional condition that determines whether the package is required.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited