ModuleRequirements class
Defines the package and code-generation requirements of an FKIT module.
Constructors
-
ModuleRequirements({required Map<
String, ModulePackage> packages, required Map<String, ModulePackage> devPackages, required bool flutterGen, required bool buildRunner}) -
Creates module requirements with the specified configuration.
const
- ModuleRequirements.empty()
-
Creates an empty module requirements configuration.
const
- ModuleRequirements.fromMap(Map map)
-
Creates module requirements from the provided
map.factory
Properties
- buildRunner → bool
-
Whether build runner execution is required.
final
-
devPackages
→ Map<
String, ModulePackage> -
The development packages required by the module.
final
- flutterGen → bool
-
Whether Flutter code generation is required.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
packages
→ Map<
String, ModulePackage> -
The runtime packages required by the module.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited