resolveVariable method
Resolves the generated variable name for the specified component.
The resolved class name is converted to lower camel case.
Implementation
String resolveVariable(String component) {
final className = resolveClass(component);
return className[0].toLowerCase() + className.substring(1);
}