EnvironmentStep class
Collects environment configuration during the initialization wizard.
- Inheritance
-
- Object
- WizardStep<
EnvironmentConfig> - EnvironmentStep
Constructors
- EnvironmentStep({required FlavorSetup flavors, EnvironmentConfig? current})
- Creates an environment configuration step.
Properties
- current → EnvironmentConfig?
-
The existing environment configuration.
final
- flavors → FlavorSetup
-
The flavor configuration used to determine environment targets.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
collect(
) → EnvironmentConfig -
Collects and returns the value produced by this wizard step.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited