FlavorStep class

Collects flavor configuration during the initialization wizard.

Inheritance

Constructors

FlavorStep(PlatformSetup platforms)
Creates a flavor configuration step for the specified platforms.

Properties

hashCode int
The hash code for this object.
no setterinherited
platforms PlatformSetup
The platform configuration used when collecting flavor settings.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

collect() FlavorSetup
Collects and returns the value produced by this wizard step.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited